@@ -88,6 +88,8 @@ class Model(object):
             for prop_name, value in kwargs.iteritems():
                 if prop_name in self._properties:
                     setattr(self, prop_name, value)
+                else:
+                    assert 0, 'unknown property: %s' % prop_name
     
     def save(self):
         pk = self._data.pop('__pk__', None)
@@ -355,6 +357,19 @@ class CompressedUnicodeProperty(CompressedStringProperty):
         return value.decode(self.internal_encoding, self.encoding_errors)
 
 
+class CompressedProperty(CompressedStringProperty):
+    def __init__(self, dumper='marshal', *args, **kwargs):
+        __import__(dumper)
+        self.dumper = sys.modules[dumper]
+        super(CompressedProperty, self).__init__(*args, **kwargs)
+    def encode(self, value):
+        value = self.dumper.dumps(value)
+        return super(CompressedProperty, self).encode(value)
+    def decode(self, value):
+        value = super(CompressedProperty, self).decode(value)
+        return self.dumper.loads(value)
+
+
 class DictDBM(dict):
     '''Dummy dbm for tests'''
     def __init__(self, filename=None):
